:orphan:

Why Use a Style Guide?
""""""""""""""""""""""

Style guides are important because they ensure consistency in the content, look, and feel of a book or a website.

Remember, a style guide is only useful if it is used, updated, and enforced.  Style Guides are useful for engineering-related documentation, sales and marketing materials, support docs, community contributions, and more.

As changes are made to the overall Ansible site design, be sure to update this style guide with those changes. Or, should other resources listed below have major revisions, consider including company information here for ease of reference.

This style guide incorporates current Ansible resources and information so that overall site and documentation consistency can be met.

.. raw:: html

   <blockquote class="note info">

   "If you don't find it in the index, look very carefully through the entire catalogue."
    ― Sears, Roebuck and Co., 1897 Sears Roebuck & Co. Catalogue

.. raw:: html

   </blockquote>
